==> hs-vte-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/vte-0.12.0/register.sh <==
#!/bin/sh
echo 'name: vte
version: 0.12.0
id: vte-0.12.0-00417b6f6f56eb1c0dc1c63914546b85

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: The VTE library inserts terminal capability strings into a trie, and then
             uses it to determine if data received from a pseudo-terminal is a control
             sequence or just random data. The sample program "interpret" illustrates
             more or less what the widget sees after it filters incoming data.
category: Graphics
author: Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.Vte.Vte
hidden-modules: Graphics.UI.Gtk.Vte.Structs
                Graphics.UI.Gtk.Vte.Types Graphics.UI.Gtk.Vte.Signals
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/vte-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/vte-0.12.0
              /usr/local/lib
hs-libraries: HSvte-0.12.0
extra-libraries: vte gtk-x11-2.0 gdk-x11-2.0 atk-1.0 pangocairo-1.0
                 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage
                 gdk_pixbuf-2.0 pangoft2-1.0 Xfixes pango-1.0 m freetype fontconfig
                 gio-2.0 gobject-2.0 gmodule-2.0 gthread-2.0 glib-2.0 cairo X11
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/vte-0.0
              /usr/local/include/glib-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gtk-2.0 /usr/local/include/gio-unix-2.0/
              /usr/local/include/cairo /usr/local/lib/gtk-2.0/include
              /usr/local/include/atk-1.0 /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         glib-0.12.0-8144dd6b871a3f77547c0bef30f04b3e
         gtk-0.12.0-a4fda87069ff09531b8c7279ba868f94
         haskell98-1.1.0.1-b5235617d15eeebf246dacfc99755a36
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         pango-0.12.0-7fcdc5f504aa781bc2b80ff49775a65e
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/vte-0.12.0/html/vte.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/vte-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-vte-0.12.1.tbz: lib/ghc-7.0.4/cabal/vte-0.12.1/register.sh <==
#!/bin/sh
echo 'name: vte
version: 0.12.1
id: vte-0.12.1-b7a60a1575f1dab60f9b18dd6bb12fb7

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: The VTE library inserts terminal capability strings into a trie, and then
             uses it to determine if data received from a pseudo-terminal is a control
             sequence or just random data. The sample program "interpret" illustrates
             more or less what the widget sees after it filters incoming data.
category: Graphics
author: Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.Vte.Vte
hidden-modules: Graphics.UI.Gtk.Vte.Structs
                Graphics.UI.Gtk.Vte.Types Graphics.UI.Gtk.Vte.Signals
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/vte-0.12.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/vte-0.12.1
              /usr/local/lib
hs-libraries: HSvte-0.12.1
extra-libraries: vte gtk-x11-2.0 gdk-x11-2.0 atk-1.0 pangocairo-1.0
                 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage
                 gdk_pixbuf-2.0 pangoft2-1.0 Xfixes pango-1.0 m freetype fontconfig
                 gio-2.0 gobject-2.0 gmodule-2.0 gthread-2.0 glib-2.0 cairo X11
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/vte-0.0
              /usr/local/include/glib-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gtk-2.0 /usr/local/include/gio-unix-2.0/
              /usr/local/include/cairo /usr/local/lib/gtk-2.0/include
              /usr/local/include/atk-1.0 /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         glib-0.12.2-14d626c7282f5f31da9b4a299a29106c
         gtk-0.12.2-eb6577e503c9105a0b596523a2dbc206
         pango-0.12.2-940a57a1d080812b6ad7997572bc4304
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/vte-0.12.1/html/vte.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/vte-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
